# WGS Analysis Python Code

A collection of useful functions for analyzing and plotting WGS data.

## Build for pip

```
python setup.py build
python setup.py build_ext --force sdist
twine upload --repository pypi dist/*
```

